Ċertifikati | OiRA
Description: Skont l-approċċ meħud mis-sieħeb nazzjonali/mill-iżviluppatur tal-għodda tal-OiRA, jista’ jkun possibbli li jinkiseb ċertifikat għall-valutazzjoni tar-riskji tiegħek. Għal dettalji dwar il-vantaġġi ta’ ċertifikati bħal dawn, jekk jogħġbok ikkuntattja lis-sieħeb nazzjonali tal-OiRA tiegħek.

Temi

# Ċertifikati

Skont l-approċċ meħud mis-sieħeb nazzjonali/mill-iżviluppatur tal-għodda tal-OiRA, jista’ jkun possibbli li jinkiseb ċertifikat għall-valutazzjoni tar-riskji tiegħek. Għal dettalji dwar il-vantaġġi ta’ ċertifikati bħal dawn, jekk jogħġbok ikkuntattja lis-sieħeb nazzjonali tal-OiRA tiegħek.

Kif tikseb ċertifikat

## Agħmel valutazzjoni tar-riskji sħiħa

Hekk kif tkun qed taħdem bil-valutazzjoni tar-riskji tiegħek, l-OiRA se tirreġistra l-progress tiegħek. Ladarba tkun ivvalutajt għadd ta’ riskji, l-għodda tinformak dwar il-possibbiltà li tikseb ċertifikat mat-tlestija tal-valutazzjoni tar-riskji sħiħa. Kull sieħeb nazzjonali/żviluppatur tal-għodda tal-OiRA jistabbilixxi l-limitu (perċentwali) għal kif tiġi definita valutazzjoni tar-riskji “sħiħa”. Iċ-ċertifikat huwa disponibbli permezz tal-buttuna “Status” fil-menu fuq ix-xellug tal-iskrin.

Il-paġna tal-istatus turi li hemm ċertifikat disponibbli.

## Ara u ppubblika ċ-ċertifikat tiegħek

Meta tikklikkja l-buttuna “Ara ċ-ċertifikat”, inti tintalab iddaħħal l-isem tal-kumpanija li għandu jidher fuq iċ-ċertifikat. Skont is-settings nazzjonali, tista’ tintalab iddaħħal aktar data biex tiżgura li ċ-ċertifikat jagħti l-informazzjoni kollha li għandek tipprovdi.

Daħħal l-informazzjoni kollha meħtieġa għaċ-ċertifikat.

Jekk timmarka l-kaxxa mmarkata “Agħmel Pubbliku”, tiġi tidher link unika (URL) għaċ-ċertifikat tiegħek. Ikkopja din il-link u ikkondividiha mal-persuni rilevanti bħala prova li tkun wettaqt il-valutazzjoni tar-riskji tiegħek.

Nota: Hija biss id-data murija f’din il-paġna li se ssir pubblika. Din il-link mhijiex disponibbli mill-menu tas-sit web tal-OiRA — hija speċifika għalik. Madankollu, teoretikament, kull min jibbrawżja l-internet jista’ jara ċ-ċertifikat li ħloqt inti!

Iċ-ċertifikat juri biss li inti weġibt għal ċertu numru ta’ riskji fl-għodda tal-valutazzjoni tar-riskji, iżda ma jagħti l-ebda informazzjoni oħra. It-tweġibiet speċifiċi għall-valutazzjoni tar-riskji mogħtija meta titlesta l-għodda tal-OiRA tista’ tarahom inti biss u ħadd aktar.

Scroll to top Load toolbar…
Back

## 5-certificates.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More